% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods_LRTest.R
\name{BootLRTest}
\alias{BootLRTest}
\title{Bootstrap Likelihood Ratio Test}
\usage{
BootLRTest(Y, p, k0, k1, control = list())
}
\arguments{
\item{Y}{Series to be tested. Must be a (\code{T x q}) matrix.}

\item{p}{Number of autoregressive lags. Must be greater than or equal to 0.}

\item{k0}{Number of regimes under null hypothesis. Must be greater than or equal to 1.}

\item{k1}{Number of regimes under alternative hypothesis. Must be greater than \code{k0}.}

\item{control}{List with test procedure options including: 
\itemize{
  \item{\code{B}: }{Integer determining the number of bootstrap simulations. Default is set to \code{999}.}
  \item{\code{burnin}: }{Number of simulated observations to remove from beginning. Default is \code{100}.}
  \item{\code{converge_check}: }{String of NULL determining if convergence of model(s) should be verified. Allowed inputs are: "null", "alt", "both", or \code{NULL}. If \code{NULL} (default) no model convergence is verified.}
  \item{\code{workers}: }{Integer determining the number of workers to use for parallel computing version of test. Note that parallel pool must already be open. Default is \code{0}.}
  \item{\code{mdl_h0_control}: }{List with restricted model options. See \code{\link{Nmdl}}, \code{\link{ARmdl}}, \code{\link{VARmdl}}, \code{\link{HMmdl}}, \code{\link{MSARmdl}}, or \code{\link{MSVARmdl}} documentation for available and default values.}
  \item{\code{mdl_h1_control}: }{List with unrestricted model options. See \code{\link{HMmdl}}, \code{\link{MSARmdl}}, or \code{\link{MSVARmdl}} documentation for available and default values.}
}}
}
\value{
List of class \code{LMCLRTest} (\code{S3} object) with attributes including: 
\itemize{
  \item{\code{mdl_h0}: }{List with restricted model attributes. See \code{\link{Nmdl}}, \code{\link{ARmdl}}, \code{\link{VARmdl}}, \code{\link{HMmdl}}, \code{\link{MSARmdl}}, or \code{\link{MSVARmdl}} documentation for return values.}
  \item{\code{mdl_h0}: }{List with unrestricted model attributes. See \code{\link{HMmdl}}, \code{\link{MSARmdl}}, or \code{\link{MSVARmdl}} documentation for return values.}
  \item{\code{LRT_0}: }{Value of test statistic from observed data.}
  \item{\code{LRN}: }{A (\code{N x 1}) vector of test statistics from data simulated under the null hypothesis.}
  \item{\code{pval}: }{P-value of Local Monte Carlo Likelihood Ratio Test.}
  \item{\code{LRN_cv}: }{Vector with 90\%, 95\%, and 99\% Monte Carlo critical values (from vector \code{LRN}).}
  \item{\code{control}: }{List with test procedure options used.}
}
}
\description{
This function performs the bootstrap likelihood ratio 
test discussed in Qu & Zhuo (2021) and Kasahara & Shimotsu (2018).
}
\references{
Qu, Zhongjun, and Fan Zhuo. 2021. “Likelihood Ratio-Based Tests for Markov Regime Switching.” \emph{The Review of Economic Studies} 88 (2): 937–968.

Kasahara, Hiroyuk, and Katsum Shimotsu. 2018. “Testing the number of regimes in Markov regime switching models.” \emph{arXiv preprint arXiv:1801.06862}.

Rodriguez Rondon, Gabriel and Jean-Marie Dufour. 2022. “Monte Carlo Likelihood Ratio Tests for Markov Switching Models.” \emph{Unpublished manuscript}.
}
